#
# spec file for package rhash
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define major   0
Name:           rhash
Version:        1.3.8
Release:        1.1
Summary:        Recursive Hasher
License:        MIT
Group:          Productivity/File utilities
URL:            https://github.com/rhash/RHash
Source0:        RHash-%{version}.tar.gz
Recommends:     %{name}-lang

%description
RHash (Recurcive Hasher) is a console utility for computing and
verifying magnet links and hash sums of files.
It supports CRC32, MD4, MD5, SHA1/SHA2, Tiger, DC++ TTH, BitTorrent
BTIH, AICH, eDonkey hash, GOST R 34.11-94, RIPEMD-160, HAS-160, EDON-R,
Whirlpool and Snefru hash algorithms. Hash sums are used to ensure and
verify integrity of large volumes of data for a long-term storing or
transferring.

Program features:
 * Calculation of Magnet links and EDonkey 2000 links.
 * Output in a predefined (SFV, BSD-like) or a user-defined format.
 * Updating crc files (adding hash sums of files missing in the crc
   file).
 * Ability to process directories recursively.

%package -n librhash%{major}
Summary:        LibRHash Shared Library
Group:          System/Libraries

%description -n librhash%{major}
LibRHash is a professional, portable, thread-safe C library for
computing a wide variety of hash sums, such as CRC32, MD4, MD5, SHA1,
SHA256, SHA512, AICH, ED2K, Tiger, DC++ TTH, BitTorrent BTIH, GOST R
34.11-94, RIPEMD-160 HAS-160, EDON-R, Whirlpool and Snefru.
Hash sums are used to ensure and verify integrity of large volumes of
data for a long-term storing or transferring.

%package devel
Summary:        Headers and Static Library for LibRHash
Group:          Development/Libraries/C and C++
Requires:       librhash%{major} = %{version}
Provides:       librhash-devel = %{version}
Obsoletes:      librhash-devel < 1.3.1

%description devel
LibRHash is a professional, portable, thread-safe C library for
computing a wide variety of hash sums, such as CRC32, MD4, MD5, SHA1,
SHA256, SHA512, AICH, ED2K, Tiger, DC++ TTH, BitTorrent BTIH, GOST R
34.11-94, RIPEMD-160 HAS-160, EDON-R, Whirlpool and Snefru.
Hash sums are used to ensure and verify integrity of large volumes of
data for a long-term storing or transferring.

This package includes LibRHash development files.

%lang_package

%prep
%setup -q -n RHash-%{version}

%build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
%{_configure} --prefix=%{_prefix} \
--exec-prefix=%{_prefix} \
--bindir=%{_bindir} \
--sysconfdir=%{_sysconfdir} \
--libdir=%{_libdir} \
--mandir=%{_mandir} \
--enable-lib-shared \
--enable-gettext

# Parallel make_build fails on older versions
# Use OPTLDFLAGS="" not to strip binaries.
make ADDCFLAGS="-rdynamic" OPTLDFLAGS=""

%install
%make_install install-lib-so-link install-lib-headers install-gmo
%find_lang %{name} %{?no_lang_C}

%check
make \
    OPTFLAGS="%{optflags}" \
    ADDCFLAGS="-DUSE_OPENSSL -DOPENSSL_RUNTIME -rdynamic" \
    ADDLDFLAGS="-ldl" \
    LD_LIBRARY_PATH="../librhash" \
    test

%post -n librhash%{major} -p /sbin/ldconfig
%postun -n librhash%{major} -p /sbin/ldconfig

%files
%license COPYING
%doc ChangeLog README.md
%config(noreplace) %{_sysconfdir}/rhashrc
%{_bindir}/ed2k-link
%{_bindir}/edonr256-hash
%{_bindir}/edonr512-hash
%{_bindir}/gost-hash
%{_bindir}/has160-hash
%{_bindir}/magnet-link
%{_bindir}/rhash
%{_bindir}/sfv-hash
%{_bindir}/tiger-hash
%{_bindir}/tth-hash
%{_bindir}/whirlpool-hash
%{_mandir}/man1/ed2k-link.1%{?ext_man}
%{_mandir}/man1/edonr256-hash.1%{?ext_man}
%{_mandir}/man1/edonr512-hash.1%{?ext_man}
%{_mandir}/man1/gost-hash.1%{?ext_man}
%{_mandir}/man1/has160-hash.1%{?ext_man}
%{_mandir}/man1/magnet-link.1%{?ext_man}
%{_mandir}/man1/rhash.1%{?ext_man}
%{_mandir}/man1/sfv-hash.1%{?ext_man}
%{_mandir}/man1/tiger-hash.1%{?ext_man}
%{_mandir}/man1/tth-hash.1%{?ext_man}
%{_mandir}/man1/whirlpool-hash.1%{?ext_man}

%files -n librhash%{major}
%{_libdir}/librhash.so.%{major}*

%files devel
%license COPYING
%doc ChangeLog README.md
%{_includedir}/rhash.h
%{_includedir}/rhash_torrent.h
%{_libdir}/librhash.so

%files lang -f %{name}.lang

%changelog
* Fri Feb 22 2019 dliw@posteo.net
- Update to version 1.3.8
  Version 1.3.8
  * rename Windows encoding options: --ansi to --win, --oem to --dos
  * support GOST R 34.11-2012 hash function (options: --gost12-256, --gost12-512)
  * changed the short option `-G' to be alias of --gost12-256
  * changed printf format token `%%g' to be alias of %%{gost12-256}
  Version 1.3.7
  * option `--message==<string>' to calculate a hash for string
  * option `--crc32c' for CRC32C hash function
  * changed magnet link short option from '-m' to '-g'
  * Bugfix: `--file-list=-' shall read a file list from stdin
  * speedup CRC32 hash function
  Version 1.3.6
  * support --file-list option
  * librhash: speedup sha3
  * Bugfix: fix --follow option
  * better MSYS and CygWin support
  * configuration script
  * Bugfix: broken binary hash output
- Remove rhash-1.3.0-shared.patch
* Wed Aug 16 2017 mpluskal@suse.com
- Update to version 1.3.5:
  * look for locales directory at PROGRAM_DIRECTORY\locale on
    Windows
  * look for config at PROGRAM_DIRECTORY\rhashrc on Windows
* Tue Jun 13 2017 mpluskal@suse.com
- Do not use openssl (avoid build cycle with cmake)
* Fri Jun  2 2017 mpluskal@suse.com
- Update to version 1.3.4:
  * Compilation fixes for FreeBSD
  * return non zero exit code if a file was not found
- Refresh rhash-1.3.0-shared.patch
* Tue Aug  5 2014 lazy.kent@opensuse.org
- Update to 1.3.3.
  * Ctrl-C now interrupts benchmarking.
  * Set a boolean in config to true by a string `true', `on' or
    `yes'.
  * Changed the `-p' format names of sha* families, see manpage.
  * Fixed test_rhash.sh script failing on the en_US.UTF-8 locale.
  * LibRHash now exports torrent functions.
  * Support torrents with more than one announce url.
  * Update the SHA3 algorithm to follow the changes of the FIPS 202
    draft.
  * Option --exclude for skipping some files during recursive
    scanning.
  * librhash: small optimization of Whirlpool.
* Sat Jul  5 2014 lazy.kent@opensuse.org
- Update to 1.3.2.
  * BTIH piece length calculation updated to follow the uTorrent
    algorithm change.
  * Option --follow for following symlinks to directories.
  * Ignore non-regular files while scanning directories
    recursively.
  * Report warnings on files locked by some processes.
* Fri Jan 10 2014 lazy.kent@opensuse.org
- Update to 1.3.1.
  Bugfix: corrected sha3-224 for big-endian processors.
  * Fixed 'value too large' error on 32-bit Linux.
  * Improved directory scanning.
  * Exclude the files specified by -o and -l from processing.
- Drop rhash-remove-assert.patch (fixed upstream).
- Rename librhash-devel package to rhash-devel.
* Sun Oct 27 2013 lazy.kent@opensuse.org
- Add rhash-remove-assert.patch: remove wrong assertion statement
  (https://sourceforge.net/p/rhash/bugs/43/).
* Wed Sep 18 2013 lazy.kent@opensuse.org
- Update to 1.3.0.
  * Bugfixes:
    + %%{mtime} formating option was broken.
    + Fixed memory leaks.
    + Fixed output of percents when two or more files are hashed.
  * Supported SHA3 (Keccak) hash function.
  * Updated translations: de, es, gl, it.
  * Add baselibs.conf as a source.
  * Refresh rhash-shared.patch.
* Mon Dec 24 2012 lazy.kent@opensuse.org
- Update to 1.2.10.
  * Bugfixes:
    + Different BTIH were generated for the same file.
    + Path issue with verification of hash files.
    + Non-zero exit code if some files were not found.
    + Incorrect GOST hash for ("\FF" x 64) on non-x86 CPU.
  * Improved Ctrl-C processing.
  * Shortcut -k for --check-embedded.
  * Update rhash-*-shared.patch.
* Fri Apr 13 2012 lazy.kent@opensuse.org
- Update to 1.2.9.
  * Option --bt-batch for batch torrents.
- Updated "shared" patch.
- Splitted off language package.
* Mon Sep 19 2011 lazy.kent@opensuse.org
- Update to 1.2.8.
  * Fix bugs (sf#3391587).
- Dropped obsolete patches (fixed upstream).
- Build shared library.
- Build rhash against shared library (added patch).
* Tue Sep  6 2011 lazy.kent@opensuse.org
- Build shared library.
* Sat Aug 20 2011 lazy.kent@opensuse.org
- Added fix_crash and memfix patches (sf#3391587).
* Sun Aug 14 2011 lazy.kent@opensuse.org
- Update to 1.2.7.
  * Supported verification of sha256, sha512 and other hash sum.
  * Bugfix: percents option was broken in v1.2.6.
* Wed Jun 15 2011 lazy.kent@opensuse.org
- Update to 1.2.6.
  * Bugfix: --output failed for cyrillic file name.
- Updated description.
- Updated make options.
* Sat May 28 2011 lazy.kent@opensuse.org
- Update to 1.2.5.
  * Option --openssl allows to replace some algorithms
    by the OpenSSL ones.
  * Bugfix: incorrect recursive traversing of very long UTF-8
    filepaths.
  * Bugfix: corrected calculation of BTIH hash and torrent files.
- Build requires libopenssl-devel.
- Use full URL for source.
* Fri Apr 15 2011 lazy.kent@opensuse.org
- Update to 1.2.4.
  * Option --benchmark-raw for machine-readable benchmark output
    format.
  * On Intel/AMD CPUs benchmark now prints the clocks-per-byte
    value.
  * Bugfix: repaired --path-separator on linux/unix.
* Mon Apr  4 2011 lazy.kent@opensuse.org
- Update to 1.2.3.
  * One-line percent for linux/unix.
  * Bugfix: verification of base2-like formated md5 hash sums.
* Sun Jan 23 2011 lazy.kent@opensuse.org
- update to 1.2.2.
  * Bugfix: --accept/--crc-accept were not working since 1.1.9.
* Wed Nov 24 2010 lazy.kent.suse@gmail.com
- Initial package created - 1.2.0.
